# Changelog

## cmdtools v2.5.0

### Changes from commit

- removed `AioCmd` class by @HugeBrain16 [#3b174fa](https://github.com/HugeBrain16/cmdtools/commit/3b174faef6ada243ab4823d98b2eae91ed1d6b18)
- change run method to sync @HugeBrain16 [#6865df7](https://github.com/HugeBrain16/cmdtools/commit/6865df7db65f900ae4ccc20537d071d8545628f5)

**Full Changelog**: https://github.com/HugeBrain16/cmdtools/compare/2.4.9...2.5.0

## cmdtools v2.4.9

### Changes from commit

- use `__` prefix and suffix for aliases property by @hugebrain16 [#fd5df39](https://github.com/HugeBrain16/cmdtools/commit/fd5df392c59ffec7898278b01cbc4ba9e680d380)
- use default args instead of using Arbitrary Keyword Argument by @hugebrain16 [#02c9d8f](https://github.com/HugeBrain16/cmdtools/commit/02c9d8fa7b4c7d207df0c30cb8e056f6fd327ec0)
